@@ -1,15 +1,16 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2020-2024, by Samuel Williams.
+# Copyright, 2020-2025, by Samuel Williams.
 
-require_relative 'method'
+require_relative "method"
 
 module Decode
 	module Language
 		module Ruby
 			# A Ruby-specific function.
 			class Function < Method
+				# Generate a nested name for the function.
 				def nested_name
 					".#{@name}"
 				end
